MsgSettingsWrite

Struct MsgSettingsWrite 

pub struct MsgSettingsWrite {
    pub sender_id: Option<u16>,
    pub setting: SbpString<Vec<u8>, Multipart>,
}
Write device configuration settings (host => device)

The setting message writes the device configuration for a particular setting via A NULL-terminated and NULL-delimited string with contents “SECTION_SETTING\0SETTING\0VALUE\0” where the ‘\0’ escape sequence denotes the NULL character and where quotation marks are omitted. A device will only process to this message when it is received from sender ID 0x42. An example string that could be sent to a device is “solution\0soln_freq\010\0”.

Fields

sender_id: Option<u16>

The message sender_id

setting: SbpString<Vec<u8>, Multipart>

A NULL-terminated and NULL-delimited string with contents “SECTION_SETTING\0SETTING\0VALUE\0”