pub struct MsgSettingsWriteResp {
pub sender_id: Option<u16>,
pub status: u8,
pub setting: SbpString<Vec<u8>, Multipart>,
}Expand description
Acknowledgement with status of MSG_SETTINGS_WRITE
Return the status of a write request with the new value of the setting. If the requested value is rejected, the current value will be returned. The string field is a NULL-terminated and NULL-delimited string with contents “SECTION_SETTING\0SETTING\0VALUE\0” where the ‘\0’ escape sequence denotes the NULL character and where quotation marks are omitted. An example string that could be sent from device is “solution\0soln_freq\010\0”.
Fields
sender_id: Option<u16>The message sender_id
status: u8Write status
setting: SbpString<Vec<u8>, Multipart>A NULL-terminated and delimited string with contents “SECTION_SETTING\0SETTING\0VALUE\0”
Implementations
Sourceimpl MsgSettingsWriteResp
impl MsgSettingsWriteResp
Sourcepub fn write_status(&self) -> Result<WriteStatus, u8>
pub fn write_status(&self) -> Result<WriteStatus, u8>
Gets the WriteStatus stored in the status bitfield.
Returns Ok if the bitrange contains a known WriteStatus variant.
Otherwise the value of the bitrange is returned as an Err(u8). This may be because of a malformed message,
or because new variants of WriteStatus were added.
Sourcepub fn set_write_status(&mut self, write_status: WriteStatus)
pub fn set_write_status(&mut self, write_status: WriteStatus)
Set the bitrange corresponding to the WriteStatus of the status bitfield.