pub struct MsgLinuxSysState {
pub sender_id: Option<u16>,
pub mem_total: u16,
pub pcpu: u8,
pub pmem: u8,
pub procs_starting: u16,
pub procs_stopping: u16,
pub pid_count: u16,
pub time: u32,
pub flags: u8,
}Expand description
CPU, Memory and Process Starts/Stops
This presents a summary of CPU and memory utilization, including a timestamp.
Fields
sender_id: Option<u16>The message sender_id
mem_total: u16total system memory, in MiB
pcpu: u8percent of CPU used, expressed as a fraction of 256
pmem: u8percent of memory used, expressed as a fraction of 256
procs_starting: u16number of processes that started during collection phase
procs_stopping: u16number of processes that stopped during collection phase
pid_count: u16the count of processes on the system
time: u32timestamp of message, refer to flags field for how to interpret
flags: u8flags
Implementations
Sourceimpl MsgLinuxSysState
impl MsgLinuxSysState
Sourcepub fn timestamp_type(&self) -> Result<TimestampType, u8>
pub fn timestamp_type(&self) -> Result<TimestampType, u8>
Gets the TimestampType stored in the flags bitfield.
Returns Ok if the bitrange contains a known TimestampType variant.
Otherwise the value of the bitrange is returned as an Err(u8). This may be because of a malformed message,
or because new variants of TimestampType were added.
Sourcepub fn set_timestamp_type(&mut self, timestamp_type: TimestampType)
pub fn set_timestamp_type(&mut self, timestamp_type: TimestampType)
Set the bitrange corresponding to the TimestampType of the flags bitfield.