pub trait HandleParseError<T> {
// Required method
fn handle_parse_error(self) -> T;
}Expand description
A trait that is used for converting an error in parsing of a
messages into a message. A separate trait other than the Into
trait is defined because it makes it clear that it is ok to
panic inside of the handle_error function if it is not recoverable…
e.g. if the error is from an I/O error while parsing a message
Required Methods
fn handle_parse_error(self) -> T
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".